@@ -68,7 +68,7 @@ def emit(metlog, name, values, tags=None):
     for tag in tags:
         metric.add_tag(tag, tags[tag])
     for value in values:
-        metric.add_tag(value, values[value])
+        metric.add_value(value, values[value])
     metlog.info(metric)
 
 
